import React, { Fragment, useState, useEffect, useCallback, createRef, useRef } from 'react';
import { View, Text, Alert, FlatList, StyleSheet, TouchableOpacity } from 'react-native';
import Styled from 'styled-components/native';
import Header from '~/Components/Layouts/Header';
import { Search, SearchIcon, Line, TextInput, checkFilter, filterValue, ListStyle, DetailIcon, RightArrow, CreateButton,FileTextIcon, SearchTitle } from '~/Components/Listing/Search';
import Checkbox from '~/Components/UIControls/Checkbox';
import Theme from '~/Themes';
import BottomTabBarLayout from '~/Components/Layouts/BottomTabBarLayout';
import session from '~/Utils/session';
import SearchList, { SearchListContainer } from '~/Components/Listing/SearchList';
import EmptyView from '~/Components/Listing/EmptyView';
import EntitySelect from '~/Components/EntitySelect';
import { useToast } from '~/Components/UIControls/Message';
import { DateTimePicker } from '~/Components/UIControls/DateTimePicker';
import Input from '~/Components/UIControls/Input';
import Form from '~/Components/Form';
import { Util } from '~/Utils/utils';
import { useAuth } from '~/Components/Hooks';

// list item
const Item = ({item, index, onPress=()=>{}}) => {
    const zebra = index % 2 == 0 ? true : false;
    return (
        <TouchableOpacity onPress={onPress} style={{
            ...ListStyle.itemContainer, 
            borderTopWidth: 0, 
            backgroundColor: (zebra?'#fdfdfd':'#fff'),
        }}>
            <View style={{...ListStyle.horizon,flex:1}}>
                <View style={{...ListStyle.vertical,flex:1,paddingLeft:15}}>
                    <View style={{...ListStyle.horizon}}>
                        <Text style={{...ListStyle.rounded}}>{Util.get(item, "FmsManualGroup.Name")}</Text> 
                        <Text style={{...ListStyle.textLight,marginLeft:10}}>{Util.get(item, "FmsManualType.Name")}</Text> 
                        <Text style={{...ListStyle.textLight,marginLeft:10}}>{Util.get(item, "ManualNo")}</Text>
                    </View>
                    <Text style={{...ListStyle.textMedium}}>
                        {Util.get(item, "Name")}
                    </Text>
                </View>
                <View style={{...ListStyle.horizon}}>
                    <FileTextIcon />    
                </View>
            </View>
        </TouchableOpacity>
    )
}

// list and search
const Screen = (props) => {
    const navigation = props.navigation;
    const [ready, setReady] = useState(false);
    const [filters, setFilters] = useState({});
    const [list, setList] = useState(null);
    const [page, setPage] = useState(1);
    const [refreshing, setRefreshing] = useState(false);
    const pages = useRef(10);
    const { auth } = useAuth(navigation);
    const { showMessage } = useToast();
    
    // load session when mount...
    useEffect(() => {
        (async () => {
            await session.load();
            setReady(true);
        })();
    }, []);

    // search events...
    const start = () => {
        setRefreshing(true);
    }
    const success = (data, append) => {
        pages.current = data.pages;
        //console.log(data);

        if(append && page > 1) {
            setList(list.concat(data.list));
        } else {
            setList(data.list);
        }
        setRefreshing(false);
    }
    const fail = (e) => {
        showMessage(e.message);
        setRefreshing(false);
    }

    const refreshList = () => {
        setPage('refresh-' + Math.random());
    }
    console.log('auth.Update : ' + auth.Update);
    return (
        ready ? 
        <BottomTabBarLayout>
            <SearchListContainer>
                <SearchList page={page} pages={pages.current} setPage={setPage} refreshing={refreshing}
                    data={list} renderItem={({ item, index }) => {
                        return (
                            <Item item={item} index={index} onPress={() => {
                                navigation.navigate('Form', {
                                    refreshList: refreshList,
                                    action: Form.VIEW, 
                                    siteId: session.getSiteId(), 
                                    manualId: item.ManualId, 
                                    auth: auth,
                                });
                            }} />
                        )
                    }}
                    ListEmptyComponent={<EmptyView list={list} />}
                />
                {auth.Update && <CreateButton onPress={() => {
                    navigation.navigate('Form', {
                        refreshList: refreshList,
                        action: Form.CREATE, 
                        siteId: session.getSiteId(), 
                        manualId: 0, 
                        auth: auth,
                    });
                }} />}
            </SearchListContainer>

            <Search id="manual" api={`api/app/Manual?siteId=${session.getSiteId()}`} 
                    page={page} setPage={setPage} limit={50} filters={filters} sort={{field:'ManualId', order:'desc'}}
                    onStart={start} onSuccess={success} onFailure={fail} >
                <Fragment>
                    <SearchTitle title="분류" />
                    <EntitySelect style={{ marginBottom:20 }} entity="FmsManualGroup" defaultLabel="분류" emptyLabel="전체" 
                        id="ManualGroupId" name="Name" useCheck={true}
                        onChange={(item) => { filterValue([filters, setFilters], 'ManualGroupId', item.value, 'eq') }} />

                    <SearchTitle title="유형" />
                    <EntitySelect style={{ marginBottom:20 }} entity="FmsManualType" defaultLabel="유형" emptyLabel="전체" 
                        id="ManualTypeId" name="Name" useCheck={true}
                        onChange={(item) => { filterValue([filters, setFilters], 'ManualTypeId', item.value, 'eq') }} />                    

                    <SearchTitle title="매뉴얼명" />
                    <Input style={{ marginBottom:20 }} placeholder="매뉴얼명" small onChangeText={value => filterValue([filters, setFilters], 'Name', value, 'cn')} />

                </Fragment>
            </Search>
        </BottomTabBarLayout> 
        : null
    );
};

// header
Screen.navigationOptions = ({navigation}) => { 
    return { 
        header: () => <Header 
            navigation={navigation} 
            title="매뉴얼" 
            buttons={<SearchIcon id="manual" />}
        /> 
    } 
};

export default Screen;