import React, { Fragment, useState, useEffect, useCallback, createRef, useRef } from 'react';
import { View, Text, Alert, FlatList, StyleSheet, TouchableOpacity } from 'react-native';
import Styled from 'styled-components/native';
import Header from '~/Components/Layouts/Header';
import { Search, SearchIcon, Line, TextInput, checkFilter, filterValue, ListStyle, DetailIcon, RightArrow, CreateButton, SearchTitle } from '~/Components/Listing/Search';
import Checkbox from '~/Components/UIControls/Checkbox';
import Theme from '~/Themes';
import BottomTabBarLayout from '~/Components/Layouts/BottomTabBarLayout';
import session from '~/Utils/session';
import SearchList, { SearchListContainer } from '~/Components/Listing/SearchList';
import EmptyView from '~/Components/Listing/EmptyView';
import EntitySelect from '~/Components/EntitySelect';
import { useToast } from '~/Components/UIControls/Message';
import { DateTimePicker } from '~/Components/UIControls/DateTimePicker';
import Input from '~/Components/UIControls/Input';
import Form from '~/Components/Form';
import { Util } from '~/Utils/utils';
import { useAuth } from '~/Components/Hooks';

// list item
const Item = ({item, index, onPress=()=>{}}) => {
    const zebra = index % 2 == 0 ? true : false;
    return (
        <TouchableOpacity onPress={onPress} style={[ListStyle.itemContainer, {backgroundColor: (zebra?'#fdfdfd':'#fff')}]}>
            <View style={[ListStyle.vertical, { flex:1, marginRight:15 }]}>
                <Text style={[ListStyle.text]}>{Util.get(item, "Name")}</Text>
                <View style={[ListStyle.horizon, {flex:1}]}>
                    <Text style={[ListStyle.textGray, {flex:1}]}>{Util.get(item, "RegisterUserName")}</Text>
                    <Text style={[ListStyle.textGray]}>{Util.getMonthString(item, "AddDate")}</Text>
                </View>
                <View style={[ListStyle.horizon, {flex:1, marginTop:10}]}>
                    <Checkbox value={item.ApproveDate?true:false} label="결재여부" disabled={true} />
                </View>
            </View>
        </TouchableOpacity>
    )
}

// list and search
const Screen = (props) => {
    const navigation = props.navigation;
    const [filters, setFilters] = useState({});
    const [list, setList] = useState(null);
    const [page, setPage] = useState(1);
    const [refreshing, setRefreshing] = useState(false);
    const pages = useRef(10);
    const { auth, userinfo, config } = useAuth(navigation);
    const date = useRef(Util.toDateString(Util.addDate(-1)));
    const { showMessage } = useToast();

    // search events...
    const start = () => {
        setRefreshing(true);
    }
    const success = (data, append) => {
        pages.current = data.pages;
        //console.log(data);

        if(append && page > 1) {
            setList(list.concat(data.list));
        } else {
            setList(data.list);
        }
        setRefreshing(false);
    }
    const fail = (e) => {
        showMessage(e.message);
        setRefreshing(false);
    }

    const refreshList = () => {
        setPage('refresh-' + Math.random());
    }

    return (
        <BottomTabBarLayout>
            <SearchListContainer>
                <SearchList page={page} pages={pages.current} setPage={setPage} refreshing={refreshing}
                    data={list} renderItem={({ item, index }) => {
                        return (
                            <Item item={item} index={index} onPress={() => {
                                navigation.navigate('Form', {
                                    refreshList: refreshList,
                                    siteId: item.SiteId, 
                                    addDate: Util.toDateString(item.AddDate),
                                    name: item.Name,
                                    contents: item.Contents,
                                });
                            }} />
                        )
                    }}
                    ListEmptyComponent={<EmptyView list={list} />}
                />
            </SearchListContainer>

            <Search id="monthly-report-search" api={`api/app/MonthlyReport?siteId=${userinfo.SiteId}&businessAuth=${auth.Business}`} 
                    page={page} setPage={setPage} limit={50} filters={filters} sort={{field:'AddDate', order:'desc'}}
                    onStart={start} onSuccess={success} onFailure={fail} >
                <Fragment>
                    <SearchTitle title="제목" />
                    <Input style={{ marginBottom:20 }} placeholder="제목" small onChangeText={value => filterValue([filters, setFilters], 'Name', value, 'cn')} />

                    <SearchTitle title="등록일" />
                    <DateTimePicker style={{ marginBottom:5 }} placeholder="시작일" useClear={true} onChange={(newDate) => {
                        filterValue([filters, setFilters], 'AddDate', Util.toDateString(newDate), 'ge');
                    }} />
                    <DateTimePicker style={{ marginBottom:20 }} placeholder="종료일" useClear={true} onChange={(newDate) => {
                        filterValue([filters, setFilters], 'AddDate', Util.toDateString(newDate), 'le');
                    }} />

                </Fragment>
            </Search>
        </BottomTabBarLayout> 
    );
};

// header
Screen.navigationOptions = ({navigation}) => { 
    return { 
        header: () => <Header 
            navigation={navigation} 
            title="월간보고서" 
            buttons={<SearchIcon id="monthly-report-search" />}
        /> 
    } 
};

export default Screen;